# pyUsercalc

A set of Jupyter notebooks to replicate the functionality of Marc Spiegelman&#39;s UserCalc calculator in Python,
and to add disequilibrium transport and scaled reactive transport calculators. Determines U-series disequilibria
in basalts during decompression partial melting.

## Contents

* `pyUserCalc_manuscript.ipynb`: Primary Elkins and Spiegelman (2021) manuscript notebook describing derivations, model implementation, and multiple examples for running the U-series calculators.
* `UserCalc.py`:  Python file containing the UserCalc driver and model classes as well as some convenient visualization methods, and which is imported in the model notebooks.
*  `data`: Directory containing input .csv files. These files are necessary for the primary notebook to run, and can also be used as templates for additional model use.

#### Additional materials

* `pyUserCalc-v3.3.ipynb`: Simplified version of the primary Elkins and Spiegelman (2021) pyUserCalc notebook, intended for production work with the model. Now includes basic equiline plots and run logs.
* `pyDynamic_v1.0.ipynb`: Notebook containing dynamic melting tool, after Richardson and McKenzie (1994) and Zou and Zindler (2000).
* `pyDynamicConstant_v0.1.ipynb`: Simple notebook containing simple dynamic melting calculator for constant melting rates and partitioning.
* `twolayermodel.ipynb`: Notebook containing calculator tool to generate two-layer input files.
* `input_smoothing.ipynb`: Notebook containing calculator tool to attempt to smooth out discontinuous or abrupt changes in pyUserCalc input files.
* `Useries_decay_v1.1.ipynb`: Notebook that applies radioactive decay equations to calculate simple decay effects on prior pyUserCalc melting model outcomes. This is a preliminary but working draft; now includes run logs and better file exports.
* `triangular_2D_v1.1.ipynb`: Notebook containing calculator tool to integrate pyUserCalc melting model results over a simple 2D triangular regime. This is a preliminary but working draft; now includes run logs and better file exports.
* `triangular_2D_stable`: Basic notebook containing a simple calculator to integrate stable elements over a simple 2D triangular regime.

## Installation/Running

#### ENKI Cloud Server:
Instructions:

* Register for a free [GitLab account](https://gitlab.com/ENKI-portal), if you do not already have one.
* Use your GitLab account to log in to the [ENKI cloud server](https://server.enki-portal.org/hub/login). Note that logging in for the first time can take a few minutes while your server is being built.
* Once you are logged in, click "Close this Screen" button at the bottom of the welcome screen.
* In the Launcher tab, use the "Terminal" button to launch a terminal window.
* At the terminal prompt, type the following text to clone the pyUserCalc code repository to your own server, and then type Return:
`git clone https://gitlab.com/ENKI-portal/pyUsercalc.git`
* Now navigate to the `pyUserCalc` directory in the left sidebar panel and double-click to open it. To access the primary manuscript notebook, open the file `pyUserCalc_manuscript.ipynb`, again by double clicking. To access the simplified notebook version, instead open the file `pyUserCalc-v3.1.ipynb`.



#### Binder


You can also interact directly with the manuscript notebook through a binder container. To do this, click the button below:

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gl/ENKI-portal%2FpyUsercalc/master?filepath=pyUserCalc_manuscript.ipynb)

and a container will be built that can run the manuscript notebook through your own browser. This may take a few moments to start.


#### Local Install

This repository should run with a standard Jupyter installation e.g. through Anaconda (python3).  To do so, clone the repository and open it in JupyterLab. 


#### Issues, Bugs, and Requests

Have a problem or encounter a bug in the code? Or do you have a developer request for future versions and extensions? Use the "Issues" option on the left sidebar in GitLab and start a "New issue." Alternately, you can [send us an email](mailto:contact-project+enki-portal-pyusercalc-6833634-issue-@incoming.gitlab.com).

Please note that any code or notebook file labeled "DRAFT" or listed as a "preliminary draft" above has been made available for use in advance of peer-reviewed publication, which means 1) it functions but is a work in progress, 2) it will be more streamlined and cleaned up in the future, and 3) the authors should still be fully credited for their work in prep. if the tool is used for research purposes. All files in this directory are protected by an open-source CC copyright license.
